==> hibiscus.js-1.2.2.tgz: package/message/message.service.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Overlay } from '@angular/cdk/overlay';
import { ApplicationRef, ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { MessageContainerComponent } from './message-container.component';
var globalCounter = 0; // global ID counter for messages
var MessageBaseService = /** @class */ (function () {
    function MessageBaseService(overlay, containerClass, injector, cfr, appRef, _idPrefix) {
        if (_idPrefix === void 0) { _idPrefix = ''; }
        this.overlay = overlay;
        this.containerClass = containerClass;
        this.injector = injector;
        this.cfr = cfr;
        this.appRef = appRef;
        this._idPrefix = _idPrefix;
        // this._container = overlay.create().attach(new ComponentPortal(containerClass)).instance;
        this._container = this.createContainer();
    }
    MessageBaseService.prototype.remove = function (messageId) {
        if (messageId) {
            this._container.removeMessage(messageId);
        }
        else {
            this._container.removeMessageAll();
        }
    };
    MessageBaseService.prototype.createMessage = function (message, options) {
        // TODO: spread on literal has been disallow on latest proposal
        var resultMessage = __assign({}, message, {
            messageId: this._generateMessageId(),
            options: options,
            createdAt: new Date()
        });
        this._container.createMessage(resultMessage);
        return resultMessage;
    };
    MessageBaseService.prototype.config = function (config) {
        this._container.setConfig(config);
    };
    MessageBaseService.prototype._generateMessageId = function () {
        return this._idPrefix + globalCounter++;
    };
    // Manually creating container for overlay to avoid multi-checking error, see: https://github.com/NG-ZORRO/ng-zorro-antd/issues/391
    // NOTE: we never clean up the container component and it's overlay resources, if we should, we need to do it by our own codes.
    // Manually creating container for overlay to avoid multi-checking error, see: https://github.com/NG-ZORRO/ng-zorro-antd/issues/391
    // NOTE: we never clean up the container component and it's overlay resources, if we should, we need to do it by our own codes.
    MessageBaseService.prototype.createContainer = 
    // Manually creating container for overlay to avoid multi-checking error, see: https://github.com/NG-ZORRO/ng-zorro-antd/issues/391
    // NOTE: we never clean up the container component and it's overlay resources, if we should, we need to do it by our own codes.
    function () {
        var factory = this.cfr.resolveComponentFactory(this.containerClass);
        var componentRef = factory.create(this.injector); // Use root injector
        componentRef.changeDetectorRef.detectChanges(); // Immediately change detection to avoid multi-checking error
        this.appRef.attachView(componentRef.hostView); // Load view into app root
        this.overlay.create().overlayElement.appendChild(componentRef.hostView.rootNodes[0]);
        return componentRef.instance;
    };
    return MessageBaseService;
}());
export { MessageBaseService };
var MessageService = /** @class */ (function (_super) {
    __extends(MessageService, _super);
    function MessageService(overlay, injector, cfr, appRef) {
        return _super.call(this, overlay, MessageContainerComponent, injector, cfr, appRef, 'message-') || this;
    }
    // Shortcut methods
    // Shortcut methods
    MessageService.prototype.success = 
    // Shortcut methods
    function (content, options) {
        return this.createMessage({ type: 'success', content: content }, options);
    };
    MessageService.prototype.error = function (content, options) {
        return this.createMessage({ type: 'error', content: content }, options);
    };
    MessageService.prototype.info = function (content, options) {
        return this.createMessage({ type: 'info', content: content }, options);
    };
    MessageService.prototype.warning = function (content, options) {
        return this.createMessage({ type: 'warning', content: content }, options);
    };
    MessageService.prototype.loading = function (content, options) {
        return this.createMessage({ type: 'loading', content: content }, options);
    };
    MessageService.prototype.create = function (type, content, options) {
        return this.createMessage({ type: type, content: content }, options);
    };
    MessageService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    MessageService.ctorParameters = function () { return [
        { type: Overlay, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
        { type: ApplicationRef, },
    ]; };
    return MessageService;
}(MessageBaseService));
export { MessageService };

==> hibiscus.js-1.2.3.tgz: package/message/message.service.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Overlay } from '@angular/cdk/overlay';
import { ApplicationRef, ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { MessageContainerComponent } from './message-container.component';
var globalCounter = 0;
var MessageBaseService = (function () {
    function MessageBaseService(overlay, containerClass, injector, cfr, appRef, _idPrefix) {
        if (_idPrefix === void 0) { _idPrefix = ''; }
        this.overlay = overlay;
        this.containerClass = containerClass;
        this.injector = injector;
        this.cfr = cfr;
        this.appRef = appRef;
        this._idPrefix = _idPrefix;
        this._container = this.createContainer();
    }
    MessageBaseService.prototype.remove = function (messageId) {
        if (messageId) {
            this._container.removeMessage(messageId);
        }
        else {
            this._container.removeMessageAll();
        }
    };
    MessageBaseService.prototype.createMessage = function (message, options) {
        var resultMessage = __assign({}, message, {
            messageId: this._generateMessageId(),
            options: options,
            createdAt: new Date()
        });
        this._container.createMessage(resultMessage);
        return resultMessage;
    };
    MessageBaseService.prototype.config = function (config) {
        this._container.setConfig(config);
    };
    MessageBaseService.prototype._generateMessageId = function () {
        return this._idPrefix + globalCounter++;
    };
    MessageBaseService.prototype.createContainer = function () {
        var factory = this.cfr.resolveComponentFactory(this.containerClass);
        var componentRef = factory.create(this.injector);
        componentRef.changeDetectorRef.detectChanges();
        this.appRef.attachView(componentRef.hostView);
        this.overlay.create().overlayElement.appendChild(componentRef.hostView.rootNodes[0]);
        return componentRef.instance;
    };
    return MessageBaseService;
}());
export { MessageBaseService };
var MessageService = (function (_super) {
    __extends(MessageService, _super);
    function MessageService(overlay, injector, cfr, appRef) {
        return _super.call(this, overlay, MessageContainerComponent, injector, cfr, appRef, 'message-') || this;
    }
    MessageService.prototype.success = function (content, options) {
        return this.createMessage({ type: 'success', content: content }, options);
    };
    MessageService.prototype.error = function (content, options) {
        return this.createMessage({ type: 'error', content: content }, options);
    };
    MessageService.prototype.info = function (content, options) {
        return this.createMessage({ type: 'info', content: content }, options);
    };
    MessageService.prototype.warning = function (content, options) {
        return this.createMessage({ type: 'warning', content: content }, options);
    };
    MessageService.prototype.loading = function (content, options) {
        return this.createMessage({ type: 'loading', content: content }, options);
    };
    MessageService.prototype.create = function (type, content, options) {
        return this.createMessage({ type: type, content: content }, options);
    };
    MessageService.decorators = [
        { type: Injectable },
    ];
    MessageService.ctorParameters = function () { return [
        { type: Overlay, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
        { type: ApplicationRef, },
    ]; };
    return MessageService;
}(MessageBaseService));
export { MessageService };
